# main entry point for CLI applications.


import logging
import argparse


logger = logging.getLogger(__loader__.name)


def setup_logger(args):
    root_logger = logging.getLogger()
    handler = logging.StreamHandler()

    formatter = logging.Formatter(
        style="{", fmt="{levelname:s}: {name:s}: {message:s}"
    )
    handler.setFormatter(formatter)

    root_logger.addHandler(handler)
    root_logger.setLevel(args.loglevel)


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument(
        "-d",
        "--debug",
        help="Print debug-level statements",
        action="store_const",
        dest="loglevel",
        const=logging.DEBUG,
        default=logging.INFO,
    )
    parser.add_argument(
        "-L",
        "--log-file",
        help="Log to file",
        type=argparse.FileType("w"),
        metavar="FILE",
    )

    args = parser.parse_args()

    setup_logger(args)


if __name__ == "__main__":
    main()
